@@ -18,8 +18,8 @@ class UnsupportedFileFormatError(Exception):
 
 class InvalidDimensionOrderingError(Exception):
     """
-    A general exception that can be thrown when handling dimension ordering or validation. Should be provided a message
-    for the user to be given more context.
+    A general exception that can be thrown when handling dimension ordering or
+    validation. Should be provided a message for the user to be given more context.
     """
 
     def __init__(self, message: str, **kwargs):
@@ -34,11 +34,22 @@ class ConflictingArgumentsError(Exception):
     """
     This exception is returned when 2 arguments to the same function are in conflict.
     """
+
     pass
 
 
 class InconsistentShapeError(Exception):
     """
-    A general function to use when the shape returned or requested from an array operation is invalid.
+    A general function to use when the shape returned or requested from an array
+    operation is invalid.
     """
+
+    pass
+
+
+class InconsistentPixelType(Exception):
+    """
+    This exception is returned when the metadata has conflicting pixel types.
+    """
+
     pass
